@@ -240,6 +240,8 @@ class VariableOsRootTypeExt(ReadonlyVariable):
                         return RootType.Value.IsoScanFlash
                 elif "root=live:UUID" in record:
                     return RootType.Value.LiveFlash
+                elif "root=nfs:" in record:
+                    return RootType.Value.NetBoot
                 return RootType.Value.LiveCD
 
             id_dict = dict(map(link2pair,
